..
      Copyright 2011-2013 OpenStack Foundation
      All Rights Reserved.

      Licensed under the Apache License, Version 2.0 (the "License"); you may
      not use this file except in compliance with the License. You may obtain
      a copy of the License at

          http://www.apache.org/licenses/LICENSE-2.0

      Unless required by applicable law or agreed to in writing, software
      distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
      WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
      License for the specific language governing permissions and limitations
      under the License.

Welcome to Neutron's documentation!
===================================

.. include:: _intro.rst

.. We use different index pages for HTML and PDF documents for better TOC.
   Please ensure to update pdf-index.rst when you update the index below.

Installation Guide
------------------

.. toctree::
   :maxdepth: 2

   Installation Guide <install/index>

Networking Guide
----------------

.. toctree::
   :maxdepth: 3

   admin/index

Configuration Reference
-----------------------
.. toctree::
   :maxdepth: 2

   configuration/index

CLI Reference
-------------

.. toctree::
   :maxdepth: 2

   cli/index

OVN Driver
----------

.. toctree::
   :maxdepth: 2

   ovn/index

Neutron Feature Classification
------------------------------

.. toctree::
   :maxdepth: 2

   feature_classification/index

Contributor Guide
-----------------

.. toctree::
   :maxdepth: 2

   contributor/index

API Reference
-------------

Go to https://docs.openstack.org/api-ref/network/ for information
about the OpenStack Network API and its extensions.

Search
------

* :ref:`Neutron document search <search>`: Search the contents of this
  document.
* `OpenStack wide search <https://docs.openstack.org>`_: Search the wider
  set of OpenStack documentation, including forums.
